@@ -58,7 +58,7 @@ def product_visualization_export(
 
     # trigger import
     import pyautogui
-    time.sleep(0.01)
+    time.sleep(1)
     pyautogui.hotkey('ctrl', 'shift', 'i')
     pyautogui.typewrite(project_file_name, interval=0.001)
 
